@@ -24,13 +24,15 @@ import signal
 import argparse
 import logging
 import logging.handlers
-import getpass
+import subprocess
+import os
+from ericsson.deploypattern.tools.mdtcli import exec_cmd_shell
 
 from ericsson.deploypattern.lib import errors
 from ericsson.deploypattern.lib import ansibleplay
-from ericsson.deploypattern.lib.config import Config, get_config_vars_dict
+from ericsson.deploypattern.lib import config as config_lib
+from ericsson.deploypattern.lib.config import Config
 from ericsson.deploypattern.lib.inventory import inventory_command
-from ericsson.deploypattern.lib.utils import load_yaml
 from ericsson.deploypattern.plugins.deployplugins import load_plugin
 from ericsson.deploypattern.plugins.pattern import pattern
 from ericsson.deploypattern.tools import labels
@@ -40,6 +42,7 @@ from ericsson.deploypattern.tools.apt import load_deb_repo
 from ericsson.deploypattern.tools.registry import load_docker_registry
 from ericsson.deploypattern.tools import helm
 from ericsson.deploypattern.tools import bundle
+from ericsson.deploypattern.tools import mdtcli
 from ericsson.deploypattern.version import __version__
 
 # create logger
@@ -110,8 +113,35 @@ def run_pattern(deploy_pattern):
         plugin(task)
 
 
+def redirect_to_cli(command):
+    """
+    To manage Help
+    :param command:
+    :return:
+    """
+    def handle(parsed_args, unknown_args):
+        if unknown_args.count("-h") != 0 or unknown_args.count("--help") != 0:
+            cmd = 'sudo docker exec mdt-cli mdt {} {}'.format(
+                command, ' '.join(unknown_args))
+            returncode, stdout, stderr = exec_cmd_shell(cmd)
+            if returncode == 0:
+                logger.info(stdout)
+                exit(0)
+            else:
+                logger.error("stderr : " + stderr)
+                exit(1)
+            try:
+                unknown_args.remove("-h")
+                unknown_args.remove("-help")
+            except ValueError:
+                pass
+    return handle
+
+
 def parse_cmdline():
-    """ Parse command line arguments """
+    """
+    Parse command line arguments
+    """
     parser = ArgumentParser(prog="mdt",
                             usage='mdt [mdt_options] [command] [resource] [command_options]',
                             description=('''
@@ -139,9 +169,9 @@ def parse_cmdline():
     # Subparser commands
     subparsers = parser.add_subparsers(dest='cmd')
     subparsers.required = False
-    del_parser = subparsers.add_parser('delete',
-                                       usage='mdt [mdt_options] delete [resource] [command_options].',
-                                       help='Delete resource')
+    # del_parser = subparsers.add_parser('delete',
+    #                                   usage='mdt [mdt_options] delete [resource] [command_options].',
+    #                                   help='Delete resource')
     deploy_parser = subparsers.add_parser('deploy',
                                           usage='mdt [mdt_options] deploy [resource] [command_options]',
                                           help='Deploy resource')
@@ -150,11 +180,13 @@ def parse_cmdline():
                                        help='Get resource')
     init_parser = subparsers.add_parser('init',
                                         description=('''
+!!!! Command available only for MDT bootstrap !!!!
+
 Initialize the MDT software to setup the environment appropriately.
 For allinone installation the local disk will be used instead of NFS server
                                         '''),
                                         formatter_class=argparse.RawDescriptionHelpFormatter,
-                                        usage='mdt [mdt_options] init  [-i IP_ADDRESS] [-k SSH_KEY] [-g REGISTRY] [-m HELM_REPO_URL] [-d REGISTRY_NFS_ADDRESS] [-p REGISTRY_NFS_PATH] [-u USER] [-r {yum,deb}] [-a ANSIBLE_PATH]',
+                                        usage='mdt [mdt_options] init  [-i IP_ADDRESS] [-k SSH_KEY] [-g REGISTRY] [-m HELM_REPO_URL] [-d REGISTRY_NFS_ADDRESS] [-p REGISTRY_NFS_PATH] [-u USER] [-r {yum,deb}] [-a ANSIBLE_PATH] [-c 3RDPARTY_PATH] [--http-port HTTP_PORT] [--skip_load] [--stop]',
                                         help='MDT initialisation')
     load_parser = subparsers.add_parser('load',
                                         usage='mdt [mdt_options] load [resource] [command_options]',
@@ -162,9 +194,9 @@ For allinone installation the local disk will be used instead of NFS server
     reset_parser = subparsers.add_parser('reset',
                                          usage='mdt [mdt_options] reset [resource] [command_options]',
                                          help='Reset ressources')
-    set_parser = subparsers.add_parser('set',
-                                       usage='mdt [mdt_options] set [resource] [command_options]',
-                                       help='Set resource')
+    # set_parser = subparsers.add_parser('set',
+    #                                   usage='mdt [mdt_options] set [resource] [command_options]',
+    #                                   help='Set resource')
 
     # Command deploy
     # -----------------
@@ -173,33 +205,22 @@ For allinone installation the local disk will be used instead of NFS server
                                                       description='Install Helm repository on MDT node and Helm server tiller, on one master.',
                                                       usage='mdt [mdt_options] deploy helm')
 
-    deploy_k8scluster_parser = deploy_sub_parser.add_parser('k8s-cluster',
-                                                            description=('''
-Deploy the k8s-cluster, Kubernetes on the nodes masters and workers. The inventory, list of nodes, is given by the mdt-matrix file in the config bundle folder.
-The configuration of Kubernetes cluster as HA registry, HA proxy, load balancer ... are given in k8s-config file in the config bundle folder.
+    deploy_kubecluster_parser = deploy_sub_parser.add_parser('kube-cluster',
+                                                             description=('''
+Deploy the kube-cluster, Kubernetes on the nodes masters and workers. The inventory, list of nodes, is given by the mdt-matrix file in the config bundle folder.
+The configuration of Kubernetes cluster as HA registry, HA proxy, load balancer ... are given in kube-config file in the config bundle folder.
                                                 '''),
-                                                            formatter_class=argparse.RawDescriptionHelpFormatter,
-                                                            usage='mdt [mdt_options] deploy k8s-cluster')
+                                                             formatter_class=argparse.RawDescriptionHelpFormatter,
+                                                             usage='mdt [mdt_options] deploy kube-cluster')
 
-    deploy_labels_parser = deploy_sub_parser.add_parser('labels',
-                                                        description=('''
-Deploy labels on all nodes from files of the config bundle directory.
-With the option -a|--audit only display the labels to set per node.
-                                                '''),
-                                                        formatter_class=argparse.RawDescriptionHelpFormatter,
-                                                        usage='mdt [mdt_options] deploy labels [-a]')
-
-    deploy_products_parser = deploy_sub_parser.add_parser('products',
-                                                          description=('''
-Deploy the products on Kubernetes cluster nodes according to the MDT deploy packages defined in the config bundle folder.
-If a profile is set, deploy only the packages link to the profile.
-                                                '''),
-                                                          formatter_class=argparse.RawDescriptionHelpFormatter,
-                                                          usage='mdt [mdt_options] deploy products [-p PROFILE_NAME]')
+    deploy_products_parser = deploy_sub_parser.add_parser(
+        'products', add_help=False)
+    deploy_products_parser.set_defaults(
+        func=redirect_to_cli('deploy products'))
 
     deploy_volumes_parser = deploy_sub_parser.add_parser('volumes',
                                                          description=('''
-Deploy storage classes from k8s-volumes file in config bundle folder.
+Deploy storage classes from kube-volumes file in config bundle folder.
 A storage class is defined with 4 parameters:
 * name
 * type
@@ -212,21 +233,15 @@ A storage class is defined with 4 parameters:
     # --> mdt deploy helm
     # no parameter
 
-    # --> mdt deploy k8s-cluster
+    # --> mdt deploy kube-cluster
     # no parameter
 
-    # --> mdt deploy labels
-    deploy_labels_parser.add_argument("-a", "--audit",
-                                      dest="audit",
-                                      action="store_true",
-                                      help="Display the list of labels per node without deploy them")
-
     # --> mdt deploy products [-p profile_name]
-    deploy_products_parser.add_argument("-p", "--profile",
-                                        dest="profile_name",
-                                        default=None,
-                                        help="Specific profile"
-                                        )
+#    deploy_products_parser.add_argument("-p", "--profile",
+#                                        dest="profile_name",
+#                                        default=None,
+#                                        help="Specific profile"
+#                                        )
 
     # --> mdt deploy volumes
     # no parameter
@@ -234,119 +249,31 @@ A storage class is defined with 4 parameters:
     # Command reset
     # ----------------
     reset_sub_parser = reset_parser.add_subparsers(dest='cmd_reset')
-    reset_product_parser = reset_sub_parser.add_parser('products',
-                                                       description='Reset all products installed by the MDT on all nodes',
-                                                       usage='mdt [mdt_options] reset products')
+    reset_product_parser = reset_sub_parser.add_parser(
+        'products', add_help=False)
+    reset_product_parser.set_defaults(func=redirect_to_cli('reset products'))
 
-    reset_k8scluster_parser = reset_sub_parser.add_parser('k8s-cluster',
-                                                          description=('''
+    reset_kubecluster_parser = reset_sub_parser.add_parser('kube-cluster',
+                                                           description=('''
 Reset the Kubernetes cluster on all nodes and clean load balancers. The inventory, list of nodes, is given by the mdt-matrix file in the config bundle folder.
                                                 '''),
-                                                          formatter_class=argparse.RawDescriptionHelpFormatter,
-                                                          usage='mdt [mdt_options] reset k8s-cluster')
-
-    # Command set
-    # ----------------
-    set_sub_parser = set_parser.add_subparsers(dest='cmd_set')
-    set_label_parser = set_sub_parser.add_parser('label',
-                                                 description=('''
-                                  Set a label (key,value) on a node.
-2 formats to pass label parameter: <key>=<value> or <key>:<value>
-If there is already a label with same key on the node, the set label is not available.
-You have to use option --force to set label with other value.
-                                  '''),
-                                                 formatter_class=argparse.RawDescriptionHelpFormatter,
-                                                 usage='mdt [mdt_options] set label -n NODE -l LABEL [--force]')
-
-    # --> mdt set label
-    set_label_parser.add_argument("-n", "--node",
-                                  dest="node",
-                                  required=True,
-                                  help="Required - Node to label")
-    set_label_parser.add_argument("-l", "--label",
-                                  dest="label",
-                                  required=True,
-                                  help="Required - Label to add on node: key=value or key:value")
-    set_label_parser.add_argument("--force",
-                                  action="store_true",
-                                  dest="force",
-                                  help="Force to set the label on the node, even there is a label with same key on the node")
+                                                           formatter_class=argparse.RawDescriptionHelpFormatter,
+                                                           usage='mdt [mdt_options] reset kube-cluster')
 
     # Command get
     # ---------------
     get_sub_parser = get_parser.add_subparsers(dest='cmd_get')
-    get_label_parser = get_sub_parser.add_parser('label',
-                                                 description=('''
-Get all labels (k8s and mdt labels) from a node, if there is option -n or otherwise from all nodes.
-Labels are displayed with yaml format, with 2 lists per node: 1 for MDT_labels and 1 for Other_labels.
-If option -o, the yaml is saved in file which path is given by the option.
-                                  '''),
-                                                 formatter_class=argparse.RawDescriptionHelpFormatter,
-                                                 usage='mdt [mdt_options] get label [-n NODE] [--all] [-o OUTPUT_FILE]')
+    get_label_parser = get_sub_parser.add_parser('label', add_help=False)
+    get_label_parser.set_defaults(func=redirect_to_cli('get label'))
 
-    get_cfg_parser = get_sub_parser.add_parser('cfg',
-                                               description=('''
-Get the entire configuration bundle currently applied and export all files as a tgz archive.
-The output archive is created in the path given in command line with option -o.
-                                  '''),
-                                               formatter_class=argparse.RawDescriptionHelpFormatter,
-                                               usage='mdt [mdt_options] get cfg -o OUTPUT_FILE')
-
-    # --> mdt get label
-    get_label_parser.add_argument("-n", "--node",
-                                  dest="node",
-                                  default="--all",
-                                  help="Node to get label")
-    get_label_parser.add_argument("--all",
-                                  dest="node",
-                                  action="store_const",
-                                  const="--all",
-                                  help="All nodes, default value")
-    get_label_parser.add_argument("-o", "--output",
-                                  dest="output_file",
-                                  help="Path to output file")
-
-    # --> mdt get cfg
-    get_cfg_parser.add_argument("-o", "--output",
-                                required=True,
-                                dest="output_file",
-                                help="Required - Path to archive file")
-
-    # Command delete
-    # ---------------
-    del_sub_parser = del_parser.add_subparsers(dest='cmd_del')
-    del_label_parser = del_sub_parser.add_parser('label',
-                                                 description=('''
-Delete a label (key or key=value or key:value) on a node.
-Display a warning if the node doesn't exist or hasn't the key.
-                                  '''),
-                                                 formatter_class=argparse.RawDescriptionHelpFormatter,
-                                                 usage='mdt [mdt_options] delete label -n NODE -l LABEL')
-
-    del_cfg_parser = del_sub_parser.add_parser('cfg')
-
-    # --> mdt delete label -n <node> -l <label>
-    # with label key=value, key:value, key
-    del_label_parser.add_argument("-n", "--node",
-                                  dest="node",
-                                  required=True,
-                                  help="Required - Node to delete label")
-    del_label_parser.add_argument("-l", "--label",
-                                  dest="label",
-                                  required=True,
-                                  help="Required - Label to delete on node")
+    get_cfg_parser = get_sub_parser.add_parser('cfg', add_help=False)
+    get_cfg_parser.set_defaults(func=redirect_to_cli('get cfg'))
 
     # Command load
     # -------------
     load_sub_parser = load_parser.add_subparsers(dest='cmd_load')
-    load_cfg_parser = load_sub_parser.add_parser('cfg',
-                                                 description=('''
-Load the content of the given config bundle from CONF_BUNDLE_TGZ archive file or CONF_BUNDLE_DIR directory path.
-If there is already a config bundle loaded, warning message is displayed.
-Use the option --force to force the loading.
-The config bundle is saved in ''' + Config().get('bundle', 'path')),
-        formatter_class=argparse.RawDescriptionHelpFormatter,
-        usage='mdt [mdt_options] load cfg (-f CONF_BUNDLE_TGZ | -d CONF_BUNDLE_DIR) [--force]')
+    load_cfg_parser = load_sub_parser.add_parser('cfg', add_help=False)
+    load_cfg_parser.set_defaults(func=redirect_to_cli('load cfg'))
 
     load_mdtchart_parser = load_sub_parser.add_parser('chart',
                                                       description=('''
@@ -360,7 +287,7 @@ The Helm charts are pushed to the MDT Helm repository: helm_repo.
                                                        description=('''
 Load containers from CONTAINER_TGZ archive file or CONTAINER_DIR directory path.
 The containers are pushed to the MDT Docker registry (default).
-See NFS configuration to share registry with K8S HA Docker registry.
+See NFS configuration to share registry with kube HA Docker registry.
                                                   '''),
                                                        formatter_class=argparse.RawDescriptionHelpFormatter,
                                                        usage='mdt [mdt_options] load container (-f CONTAINER_TGZ | -d CONTAINER_DIR)')
@@ -391,22 +318,6 @@ The deb are pushed to the local deb repository.
                                  dest="deb_tgz",
                                  help="Path to deb tgz archive to load ")
 
-    # --> mdt load cfg [--force] -f <tar.gz> | -d <folder>
-    load_cfg_exclusive_parser = load_cfg_parser.add_mutually_exclusive_group(
-        required=True)
-    load_cfg_exclusive_parser.add_argument("-f", "--file",
-                                           dest="conf_bundle_tgz",
-                                           default=None,
-                                           help="Path of the config bundle tgz file to be loaded")
-    load_cfg_exclusive_parser.add_argument("-d", "--directory",
-                                           dest="conf_bundle_dir",
-                                           default=None,
-                                           help="Path of the config bundle directory to be loaded")
-    load_cfg_parser.add_argument("--force",
-                                 action="store_true",
-                                 dest="force",
-                                 help="Force load, if there is already a config bundle")
-
     # --> mdt load chart -f <tar.gz> | -d <folder>
     load_mdtchart_exclusive_parser = load_mdtchart_parser.add_mutually_exclusive_group(
         required=True)
@@ -428,98 +339,116 @@ The deb are pushed to the local deb repository.
                                                  dest="container_dir",
                                                  default=None,
                                                  help="Path of container directory to be loaded")
-    load_container_parser.add_argument("-r", "--registry",
-                                       dest="registry",
-                                       default=None,
-                                       help="Load containers in specific registry")
+    # TODO when uncommnet don't forget to use this parameter in load_docker_registry function call
+    # load_container_parser.add_argument("-r", "--registry",
+    #                                    dest="registry",
+    #                                    default=None,
+    # help="Load containers in specific registry")
 
     # Command init
     # -------------
-
     init_parser.add_argument("--debug",
                              action="store_true",
                              help="Enable Debug output messages")
-    init_parser.add_argument("-i", "--ip-address",
+    init_parser.add_argument("-i ", "--ip-address",
                              dest="ip_address",
                              help="IP address of the MDT to use for cluster nodes ")
-    init_parser.add_argument("-k", "--ssh-key",
+    init_parser.add_argument("-k ", "--ssh-key",
                              dest="ssh_key",
                              help="Full path to the SSH key to use for cluster node SSH connections")
-    init_parser.add_argument("-g", "--docker-registry",
+    init_parser.add_argument("-g ", "--docker-registry",
                              dest="registry",
                              help="Only if external insecure Docker registry is used: <host>:<port> ")
-    init_parser.add_argument("-m", "--helm-repository",
+    init_parser.add_argument("-m ", "--helm-repository",
                              dest="helm_repo_url",
                              help="Only if external Helm repository is used: <host>:<port> ")
-    init_parser.add_argument("-d", "--registry-nfs-address",
+    init_parser.add_argument("-d ", "--registry-nfs-address",
                              dest="registry_nfs_address",
                              help="NFS address for registry storage")
-    init_parser.add_argument("-p", "--registry-nfs-path",
+    init_parser.add_argument("-p ", "--registry-nfs-path",
                              dest="registry_nfs_path",
                              help="Remote NFS path "
                              "(with docker/registry/ path)")
-    init_parser.add_argument("-u", "--user",
+    init_parser.add_argument("-u ", "--user",
                              dest="user",
-                             default="centos",
-                             help="Linux user to connect to the remote nodes, default current user")
-    init_parser.add_argument("-r", "--repo",
+                             help="Linux user to connect to the remote nodes, default is " + Config().get('ansible', 'remote_user'))
+    init_parser.add_argument("-r ", "--repo",
                              dest="repo",
                              choices=["yum", "apt"],
                              help="Repository to use yum (rpm packages) or apt(deb packages), default yum")
-    init_parser.add_argument("-a", "--ansible-path",
+    init_parser.add_argument("-a ", "--ansible-path",
                              dest="ansible_path",
-                             default=Config().get('ansible', 'path'),
                              help="Ansible yaml path, default " + Config().get('ansible', 'path'))
+    init_parser.add_argument("-s ", "--stop",
+                             action="store_true",
+                             dest="stop",
+                             help="Stop all containers launched by MDT bootstrap")
+    init_parser.add_argument("--skip-load",
+                             action="store_true",
+                             dest="skip_load",
+                             help="Skip load MDT and 3rd party containers to init MDT bootstrap")
+    init_parser.add_argument("--http-port",
+                             dest="http_port",
+                             help="HTTP port to access MDT containers, default " + Config().get('global', 'http_port'))
+    init_parser.add_argument("-c", "--container-3rdparty-path",
+                             default=None,
+                             dest="thirdparty_path",
+                             help="Path of the 3rd party containers to load, default /opt/mfvp/deploypattern/resources")
 
     # Commands  MDT < 1.5
     #---------------------
 
-    inventory_parser = subparsers.add_parser('inventory',
-                                             help='Inventory management (MDT <1.5)')
-    inventory_parser.add_argument("--debug",
-                                  action="store_true",
-                                  help="Enable Debug output messages")
-    inventory_parser.add_argument("-l", "--list",
-                                  action="store_true",
-                                  help="List current inventory")
-    inventory_parser.add_argument("-f", "--format",
-                                  dest="format",
-                                  default="ansible",
-                                  help="list in format ansible/yaml")
-    inventory_parser.add_argument("-i", "--import",
-                                  dest="_import",
-                                  help="import inventory")
-    inventory_parser.add_argument("-e", "--export",
-                                  dest="export",
-                                  help="export inventory to ansible format")
+    # inventory_parser = subparsers.add_parser('inventory',
+    #                                          help='Inventory management (MDT <1.5)')
+    # inventory_parser.add_argument("--debug",
+    #                               action="store_true",
+    #                               help="Enable Debug output messages")
+    # inventory_parser.add_argument("-l", "--list",
+    #                               action="store_true",
+    #                               help="List current inventory")
+    # inventory_parser.add_argument("-f", "--format",
+    #                               dest="format",
+    #                               default="ansible",
+    #                               help="list in format ansible/yaml")
+    # inventory_parser.add_argument("-i", "--import",
+    #                               dest="_import",
+    #                               help="import inventory")
+    # inventory_parser.add_argument("-e", "--export",
+    #                               dest="export",
+    #                               help="export inventory to ansible format")
 
-    pattern_parser = subparsers.add_parser(
-        'pattern', help='Deploy pattern (MDT <1.5)')
-    pattern_parser.add_argument("--debug",
-                                action="store_true",
-                                help="Enable Debug output messages")
-    pattern_parser.add_argument("-i", "--install",
-                                dest="install",
-                                help="install pattern")
-    pattern_parser.add_argument("-l", "--list-config",
-                                action="store_true",
-                                help="list configuration pattern")
-    pattern_parser.add_argument("-c", "--config",
-                                dest="config",
-                                help="set pattern configuration")
-    pattern_parser.add_argument("-p", "--path",
-                                dest="pattern_path",
-                                help="set pattern configuration")
-    pattern_parser.add_argument("-r", "--run",
-                                action="store_true",
-                                help="run pattern - "
-                                "can be combined with -c/--config")
+    # pattern_parser = subparsers.add_parser(
+    #     'pattern', help='Deploy pattern (MDT <1.5)')
+    # pattern_parser.add_argument("--debug",
+    #                             action="store_true",
+    #                             help="Enable Debug output messages")
+    # pattern_parser.add_argument("-i", "--install",
+    #                             dest="install",
+    #                             help="install pattern")
+    # pattern_parser.add_argument("-l", "--list-config",
+    #                             action="store_true",
+    #                             help="list configuration pattern")
+    # pattern_parser.add_argument("-c", "--config",
+    #                             dest="config",
+    #                             help="set pattern configuration")
+    # pattern_parser.add_argument("-p", "--path",
+    #                             dest="pattern_path",
+    #                             help="set pattern configuration")
+    # pattern_parser.add_argument("-r", "--run",
+    #                             action="store_true",
+    #                             help="run pattern - "
+    #                             "can be combined with -c/--config")
+
+    parsed_args, unknown_args = parser.parse_known_args()
+
+    if hasattr(parsed_args, 'func'):
+        parsed_args.func(parsed_args, unknown_args)
 
     if len(sys.argv[1:]) == 0:
         parser.print_help()
         parser.exit(2)
 
-    return parser.parse_args()
+    return parsed_args, unknown_args
 
 
 def signal_handler(signal, frame):
@@ -528,13 +457,31 @@ def signal_handler(signal, frame):
     sys.exit(0)
 
 
+def __exec_cmd_shell(cmd, error_msg=None):
+    """
+
+    :param cmd:
+    :param error_msg:
+    :return:
+    """
+    p = subprocess.Popen(
+        cmd, shell=True, stderr=subprocess.PIPE, stdout=subprocess.PIPE)
+    (stdout, stderr) = p.communicate()
+    logger.debug(":: rc=%s for cmd='%s'" % (p.returncode, cmd))
+    if p.returncode != 0:
+        logger.info(stdout)
+        logger.info(stderr)
+        if error_msg:
+            raise errors.DeployError(error_msg)
+    return(p.returncode, stdout, stderr)
+
 def main():
     """ Main """
 
     # setup signal handler
     signal.signal(signal.SIGINT, signal_handler)
     # parse cmdline args
-    args = parse_cmdline()
+    args, unknown_args = parse_cmdline()
 
     if args.debug:
         formatter = logging.Formatter('%(levelname)s:'
@@ -555,7 +502,9 @@ def main():
         config = Config(DFN_CONF_FILE)
 
     # Launch init process
+    # Available only for MDT bootstrap
     if args.cmd == 'init':
+        # TODO Check if MDT bootstrap
         try:
             mgnt_server_init(ipaddr=args.ip_address,
                              sshkey=args.ssh_key,
@@ -565,10 +514,14 @@ def main():
                              helm_repo=args.helm_repo_url,
                              user=args.user,
                              repo=args.repo,
-                             ansible_path=args.ansible_path)
-        except Exception as e:
+                             ansible_path=args.ansible_path,
+                             skip_load=args.skip_load,
+                             stop=args.stop,
+                             thirdparty_path=args.thirdparty_path,
+                             http_port=args.http_port)
+        except Exception as msg:
             logger.error("Initialization failed: %s" %
-                         e.message, exc_info=True)
+                         msg.message, exc_info=True)
             return 1
 
     # Command mdt inventory < 1.5
@@ -576,9 +529,9 @@ def main():
     if args.cmd == 'inventory':
         try:
             inventory_command(args)
-        except Exception as e:
+        except Exception as msg:
             logger.error("Inventory command failed: %s" %
-                         e.message, exc_info=True)
+                         msg.message, exc_info=True)
             return 1
         finally:
             exit(0)
@@ -586,17 +539,17 @@ def main():
     # check if init as been done before going on
     try:
         check_init(config)
-    except Exception as e:
-        logger.error("Init must be done before: %s" % e.message)
+    except Exception as msg:
+        logger.error("Init must be done before: %s" % msg.message)
         return 1
 
     # launch deployment pattern
     if args.cmd == 'pattern':
         try:
             pattern(args)
-        except Exception as e:
+        except Exception as msg:
             logger.error("Deploying pattern failed: %s" %
-                         e.message, exc_info=True)
+                         msg.message, exc_info=True)
             return 1
 
 
@@ -608,43 +561,41 @@ def main():
         if args.cmd_deploy == 'labels':
             try:
                 labels.set_labels(args.audit)
-            except Exception as e:
-                logger.error("Deploy labels on nodes failed: %s" % e.message)
+            except Exception as msg:
+                logger.error("Deploy labels on nodes failed: %s" % msg.message)
                 return 1
 
-        if args.cmd_deploy == 'k8s-cluster':
+        if args.cmd_deploy == 'kube-cluster':
             try:
-                bundle.Bundle().deploy_k8scluster()
-            except Exception as e:
-                logger.error("Deploying pattern failed: %s" % e.message)
+                bundle.Bundle().deploy_kubecluster()
+            except Exception as msg:
+                logger.error("Deploying pattern failed: %s" % msg.message)
                 return 1
+            # Update mdt_api_products with Docker and Helm parameters after
+            # Kube cluster deployment
 
         if args.cmd_deploy == "helm":
             try:
                 inventory = bundle.Bundle().get_inventory()
-                k8s_vars_dict = bundle.Bundle().get_vars_k8s_config()
+                kube_vars_dict = bundle.Bundle().get_vars_kube_config()
                 # Deploy Helm server (container tiller) only on one master with deployment (replicas=1)
                 # Add service to expose Helm server
                 result = ansibleplay.AnsibleRunner().playbook(
                     host_list=inventory,
                     playbooks="deploy_helm",
-                    vars=get_config_vars_dict(),
-                    extra_vars=k8s_vars_dict)
+                    vars=config_lib.get_config_vars_dict(),
+                    extra_vars=kube_vars_dict)
                 logger.debug("result : %s" % result)
                 if result != 0:
                     raise errors.AnsibleError(
                         "Ansible playbook failed : deploy_helm ")
 
-            except Exception as e:
-                logger.error("Install Helm failed: %s" % e.message)
+            except Exception as msg:
+                logger.error("Install Helm failed: %s" % msg.message)
                 return 1
 
         if args.cmd_deploy == 'products':
-            try:
-                bundle.Bundle().deploy_products(args.profile_name)
-            except Exception as e:
-                logger.error("Deploy products failed: %s" % e.message)
-                return 1
+            mdtcli.call_mdt_cli('deploy', 'products', unknown_args)
 
         if args.cmd_deploy == "volumes":
             bundle.Bundle().deploy_volumes()
@@ -654,22 +605,24 @@ def main():
     if args.cmd == 'reset':
         if args.cmd_reset == 'products':
             # Reset all products
-            helm.reset_all()
+            mdtcli.call_mdt_cli('reset', 'products', unknown_args)
 
-        if args.cmd_reset == 'k8s-cluster':
+        if args.cmd_reset == 'kube-cluster':
             try:
-                bundle.Bundle().reset_k8scluster()
-            except Exception as e:
-                logger.error("Reset K8S failed: %s" % e.message)
+                bundle.Bundle().reset_kubecluster()
+            except Exception as msg:
+                logger.error("Reset kube failed: %s" % msg.message)
                 return 1
+            # Update mdt_api_products with Docker and Helm parameters after
+            # Kube cluster reset
+            # TODO: is it useful ?
 
     # Command mdt load
     # -------------------------
     if args.cmd == 'load':
         if args.cmd_load == 'cfg':
             # load config bundle files:
-            bundle.Bundle().load_bundle(args.conf_bundle_tgz,
-                                        args.conf_bundle_dir, args.force)
+            mdtcli.call_mdt_cli('load', 'cfg', unknown_args)
 
         if args.cmd_load == 'chart':
             try:
@@ -692,65 +645,44 @@ def main():
         if args.cmd_load == 'container':
             try:
                 load_docker_registry(
-                    args.container_tgz, args.container_dir, args.registry)
+                    args.container_tgz, args.container_dir)
+# args.container_tgz, args.container_dir, args.registry) TODO use when
+# regitry will be used
 
-            except Exception as e:
-                logger.error("Loading Containers failed: %s" % e.message)
+            except Exception as msg:
+                logger.error("Loading Containers failed: %s" % msg.message)
                 return 1
 
         if args.cmd_load == 'rpm':
             try:
                 load_yum_repo(args.rpm_tgz)
 
-            except Exception as e:
-                logger.error("Loading Rpm failed: %s" % e.message)
+            except Exception as msg:
+                logger.error("Loading Rpm failed: %s" % msg.message)
                 return 1
 
         if args.cmd_load == 'deb':
             try:
                 load_deb_repo(args.deb_tgz)
 
-            except Exception as e:
-                logger.error("Loading deb failed: %s" % e.message)
-                return 1
-
-    # Command mdt-cli set
-    # ----------------------
-    if args.cmd == 'set':
-        if args.cmd_set == 'label':
-            try:
-                labels.set_label(args.node, args.label, args.force)
-            except Exception as e:
-                logger.error("Set label failed: %s" % e.message)
-                return 1
-
-    # Command mdt-cli delete
-    # ----------------------
-    if args.cmd == 'delete':
-        if args.cmd_del == 'label':
-            try:
-                labels.delete_label(args.node, args.label)
-            except Exception as e:
-                logger.error("Delete label failed: %s" % e.message)
+            except Exception as msg:
+                logger.error("Loading deb failed: %s" % msg.message)
                 return 1
 
     # Command mdt-cli get
     # ----------------------
     if args.cmd == 'get':
         if args.cmd_get == 'label':
-            try:
-                if args.node != "--all":
-                    labels.get_label(args.node, args.output_file)
-                else:
-                    labels.get_label(None, args.output_file)
-            except Exception as e:
-                logger.error("Get label failed: %s" % e.message)
-                return 1
+            # get label
+            mdtcli.call_mdt_cli('get', 'label', unknown_args)
 
         if args.cmd_get == 'cfg':
             # get config bundle files:
-            bundle.Bundle().get_bundle(args.output_file)
+            mdtcli.call_mdt_cli('get', 'cfg', unknown_args)
 
+    if len(unknown_args) > 0:
+        logger.error("Unknown arguments : {}".format(unknown_args))
+        exit(2)
     # logger.info("\n")
     return 0
 
