@@ -28,8 +28,8 @@ import logging
 from collections import namedtuple
 
 from ansible.parsing.dataloader import DataLoader
-from ansible.vars import VariableManager
-from ansible.inventory import Inventory
+from ansible.vars.manager import VariableManager
+from ansible.inventory.manager import InventoryManager
 from ansible.inventory.group import Group
 from ansible.inventory.host import Host
 from ansible.executor.playbook_executor import PlaybookExecutor
@@ -60,8 +60,8 @@ class AnsiblePlay(object):
                  options=None,
                  output=False):
 
+
         # initialize needed objects
-        self.variable_manager = VariableManager()
         self.loader = DataLoader()
         self.passwords = {}
 
@@ -87,19 +87,22 @@ class AnsiblePlay(object):
         if isinstance(host_list, list):
             for elt in host_list:
                 if isinstance(elt, dict):
-                    self.inventory = Inventory(loader=self.loader,
-                                               variable_manager=self.variable_manager,
-                                               host_list=None)
+                    self.inventory = InventoryManager(loader=self.loader,
+                                               #variable_manager=self.variable_manager,
+                                               #host_list=None)
+                                               sources=None)
                     build_inventory(self.inventory, host_list)
                     save_yaml_inventory(host_list)
                     break
 
+        # Case host_list is not None or list, then it is path ?
         if self.inventory is None:
-            self.inventory = Inventory(loader=self.loader,
-                                       variable_manager=self.variable_manager,
-                                       host_list=host_list)
+            self.inventory = InventoryManager(loader=self.loader,
+                                       #variable_manager=self.variable_manager,
+                                               #host_list=host_list)
+                                               sources=host_list)
+        self.variable_manager = VariableManager(loader=self.loader, inventory=self.inventory)
 
-        self.variable_manager.set_inventory(self.inventory)
 
         if extra_vars is not None:
             self.variable_manager.extra_vars = extra_vars
@@ -152,7 +155,7 @@ class AnsibleRunner(object):
                  become_method=None, become_user=None, check=None,
                  extra_vars=None, private_key_file=None, remote_user=None,
                  verbosity=5, listtasks=None, listtags=None, listhosts=None,
-                 syntax=None, tags=[], skip_tags=[]):
+                 syntax=None, tags=[], skip_tags=[], diff=False):
 
         Options = namedtuple('Options',
                              ['connection', 'forks', 'module_path', 'become',
@@ -160,7 +163,7 @@ class AnsibleRunner(object):
                               'become_prompt', 'check',
                               'extra_vars', 'private_key_file', 'remote_user',
                               'verbosity', 'listhosts', 'listtasks', 'listtags',
-                              'syntax', 'ssh_extra_args', 'tags', 'skip_tags'])
+                              'syntax', 'ssh_extra_args', 'tags', 'skip_tags', 'diff'])
 
         try:
             if private_key_file is None:
@@ -200,7 +203,8 @@ class AnsibleRunner(object):
             syntax=syntax,
             ssh_extra_args=ssh_extra_args,
             tags=tags,
-            skip_tags=skip_tags
+            skip_tags=skip_tags,
+            diff=diff
         )
 
     def add_tag(self, tag):
@@ -277,16 +281,16 @@ class AnsibleRunner(object):
         """
         Execute a playbook
         """
+        self._add_all_vars(extra_vars)
 
         try:
-            self._add_all_vars(extra_vars)
             play = AnsiblePlay(host_list=host_list,
                                extra_vars=extra_vars,
                                options=self.options)
-
             if vars != None:
                 play.variable_manager.options_vars = vars
 
+
             pbex=PlaybookExecutor(playbooks = [construct_playbook(playbooks)],
                                   inventory = play.inventory,
                                   variable_manager = play.variable_manager,
@@ -502,6 +506,7 @@ def run_playbook(playbook_name):
     # check if localhost and add var :
     # ansible_python_interpreter: "/usr/bin/python"
     #~ playbook = construct_playbook(playbook_name)
+    extra_vars=get_config_vars_dict()
     result = AnsibleRunner(). \
         playbook(host_list=[],
                  playbooks=playbook_name,
@@ -531,15 +536,20 @@ def construct_playbook(name):
     """
     Add extension .yml to playbook name
     """
+    pb_path = get_ansible_path()
     if os.path.splitext(name)[1] == '':
         pb_name = name + '.yaml'
+        playbook = os.path.join(pb_path, pb_name)
+        if not os.path.exists(playbook):
+            pb_name = name + '.yml'
+            playbook = os.path.join(pb_path, pb_name)
+            if not os.path.exists(playbook):
+                raise errors.FileNotFound('%s: ' % playbook)
     else:
         pb_name = name
-    pb_path = get_ansible_path()
-    playbook = os.path.join(pb_path, pb_name)
-
-    if not os.path.exists(playbook):
-        raise errors.FileNotFound('%s: ' % playbook)
+        playbook = os.path.join(pb_path, pb_name)
+        if not os.path.exists(playbook):
+            raise errors.FileNotFound('%s: ' % playbook)
 
     return playbook
 
